<div align = "center" >
    <h1>langful</h1>
    <a href = "https://pypi.org/project/langful" >
        <img alt = "PyPI version" src = "https://img.shields.io/pypi/v/langful?color=blue" >
    </a>
    <a href = "https://www.python.org" >
        <img alt = "Python version" src = "https://img.shields.io/badge/python-3.10+-blue" >
    </a>
    <a href = "https://opensource.org/license/mit" >
        <img alt = "license" src = "https://img.shields.io/badge/license-MIT-blue" >
    </a>
    <a href = "https://github.com/cueavy/langful" >
        <img alt = "Github issues" src = "https://img.shields.io/github/issues/cueavy/langful?color=blue" >
    </a>
    <hr>
        <p>[ English | <a href = "./README-zh_cn.md" >简体中文</a> ]</p>
    <hr>
</div>

# install

`pip install langful`

# about

[
[github](https://github.com/cueavy/langful)
|
[pypi](https://pypi.org/project/langful)
]
